@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '3.30';
+our $VERSION = '3.40';
 
 # AUTHORITY
 
@@ -43,6 +43,7 @@ sub import {
     cop => 1,
     data => 1,
     date => 1,
+    docs => 1,
     error => 1,
     false => 1,
     fault => 1,
@@ -76,6 +77,7 @@ sub import {
     regexp => 1,
     replace => 1,
     render => 1,
+    resolve => 1,
     roll => 1,
     search => 1,
     space => 1,
@@ -84,6 +86,7 @@ sub import {
     syscall => 1,
     template => 1,
     test => 1,
+    text => 1,
     then => 1,
     throw => 1,
     true => 1,
@@ -366,6 +369,16 @@ sub date ($;$@) {
   return Venus::Date->new($data)->$code(@args);
 }
 
+sub docs {
+  my (@args) = @_;
+
+  my $file = (grep -f, (caller(0))[1], $0)[0];
+
+  my $data = data($file);
+
+  return $data->docs->string(@args > 1 ? @args : (undef, @args));
+}
+
 sub error (;$) {
   my ($data) = @_;
 
@@ -531,12 +544,65 @@ sub match ($;&) {
   return $match->result;
 }
 
-sub merge (@) {
-  my (@args) = @_;
+sub merge {
+  my ($lvalue, @rvalues) = @_;
 
-  require Venus::Hash;
+  if (!$lvalue) {
+    return {};
+  }
 
-  return Venus::Hash->new({})->merge(@args);
+  my $rvalue;
+
+  if (@rvalues > 1) {
+    my $result = $lvalue;
+    $result = merge($result, $_) for @rvalues;
+    return $result;
+  }
+  else {
+    $rvalue = $rvalues[0];
+  }
+
+  if (!$rvalue) {
+    return $lvalue;
+  }
+
+  if (ref $lvalue eq 'HASH') {
+    if (ref $rvalue eq 'HASH') {
+      for my $index (keys %{$rvalue}) {
+        my $lprop = $lvalue->{$index};
+        my $rprop = $rvalue->{$index};
+        $lvalue->{$index} = (
+            ((ref($lprop) eq 'HASH') && (ref($rprop) eq 'HASH'))
+            || ((ref($lprop) eq 'ARRAY') && (ref($rprop) eq 'ARRAY'))
+          )
+          ? merge($lprop, $rprop)
+          : $rprop;
+      }
+    }
+    else {
+      $lvalue = $rvalue;
+    }
+  }
+
+  if (ref $lvalue eq 'ARRAY') {
+    if (ref $rvalue eq 'ARRAY') {
+      for my $index (0..$#{$rvalue}) {
+        my $lprop = $lvalue->[$index];
+        my $rprop = $rvalue->[$index];
+        $lvalue->[$index] = (
+            ((ref($lprop) eq 'HASH') && (ref($rprop) eq 'HASH'))
+            || ((ref($lprop) eq 'ARRAY') && (ref($rprop) eq 'ARRAY'))
+          )
+          ? merge($lprop, $rprop)
+          : $rprop;
+      }
+    }
+    else {
+      $lvalue = $rvalue;
+    }
+  }
+
+  return $lvalue;
 }
 
 sub meta ($;$@) {
@@ -746,6 +812,12 @@ sub replace ($;$@) {
   return Venus::Replace->new(@data)->$code(@args);
 }
 
+sub resolve ($;@) {
+  my ($data, @args) = @_;
+
+  return container($data, 'resolve', @args);
+}
+
 sub roll (@) {
 
   return (@_[1,0,2..$#_]);
@@ -865,6 +937,16 @@ sub test ($;$@) {
   return Venus::Test->new($data)->$code(@args);
 }
 
+sub text {
+  my (@args) = @_;
+
+  my $file = (grep -f, (caller(0))[1], $0)[0];
+
+  my $data = data($file);
+
+  return $data->text->string(@args > 1 ? @args : (undef, @args));
+}
+
 sub then (@) {
 
   return ($_[0], call(@_));
@@ -1041,7 +1123,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-3.30
+3.40
 
 =cut
 
@@ -2252,6 +2334,64 @@ I<Since C<2.40>>
 
 =cut
 
+=head2 docs
+
+  docs(Any @args) (Any)
+
+The docs function builds a L<Venus::Data> object using L<Venus::Data/docs> for
+the current file, i.e. L<perlfunc/__FILE__> or script, i.e. C<$0>, and returns
+the result of a L<Venus::Data/string> operation using the arguments provided.
+
+I<Since C<3.30>>
+
+=over 4
+
+=item docs example 1
+
+  package main;
+
+  use Venus 'docs';
+
+  # =head1 ABSTRACT
+  #
+  # Example Abstract
+  #
+  # =cut
+
+  my $docs = docs 'head1', 'ABSTRACT';
+
+  # "Example Abstract"
+
+=back
+
+=over 4
+
+=item docs example 2
+
+  package main;
+
+  use Venus 'docs';
+
+  # =head1 NAME
+  #
+  # Example #1
+  #
+  # =cut
+  #
+  # =head1 NAME
+  #
+  # Example #2
+  #
+  # =cut
+
+  my $docs = docs 'head1', 'NAME';
+
+  # "Example #1\nExample #2"
+
+=back
+
+=cut
+
 =head2 error
 
   error(Maybe[HashRef] $args) (Error)
@@ -3100,10 +3240,10 @@ I<Since C<2.50>>
 
 =head2 merge
 
-  merge(HashRef @args) (HashRef)
+  merge(Any @args) (Any)
 
-The merge function returns a hash reference which is a merger of all of the
-hashref arguments provided.
+The merge function returns a value which is a merger of all of the arguments
+provided.
 
 I<Since C<2.32>>
 
@@ -3555,6 +3695,46 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 puts
+
+  puts(Any @args) (ArrayRef)
+
+The puts function select values from within the underlying data structure using
+L<Venus::Array/path> or L<Venus::Hash/path>, optionally assigning the value to
+the preceeding scalar reference and returns all the values selected.
+
+I<Since C<3.20>>
+
+=over 4
+
+=item puts example 1
+
+  package main;
+
+  use Venus 'puts';
+
+  my $data = {
+    size => "small",
+    fruit => "apple",
+    meta => {
+      expiry => '5d',
+    },
+    color => "red",
+  };
+
+  puts $data, (
+    \my $fruit, 'fruit',
+    \my $expiry, 'meta.expiry'
+  );
+
+  my $puts = [$fruit, $expiry];
+
+  # ["apple", "5d"]
+
+=back
+
+=cut
+
 =head2 raise
 
   raise(Str $class | Tuple[Str, Str] $class, Maybe[HashRef] $args) (Error)
@@ -3797,6 +3977,52 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 resolve
+
+  resolve(HashRef $value, Any @args) (Any)
+
+The resolve function builds and returns an object via L<Venus::Container/resolve>.
+
+I<Since C<3.30>>
+
+=over 4
+
+=item resolve example 1
+
+  package main;
+
+  use Venus 'resolve';
+
+  my $resolve = resolve {};
+
+  # undef
+
+=back
+
+=over 4
+
+=item resolve example 2
+
+  package main;
+
+  use Venus 'resolve';
+
+  my $data = {
+    '$services' => {
+      log => {
+        package => "Venus/Path",
+      }
+    }
+  };
+
+  my $log = resolve $data, 'log';
+
+  # bless({...}, 'Venus::Path')
+
+=back
+
+=cut
+
 =head2 roll
 
   roll(Str $name, Any @args) (Any)
@@ -4127,6 +4353,114 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 text
+
+  text(Any @args) (Any)
+
+The text function builds a L<Venus::Data> object using L<Venus::Data/text> for
+the current file, i.e. L<perlfunc/__FILE__> or script, i.e. C<$0>, and returns
+the result of a L<Venus::Data/string> operation using the arguments provided.
+
+I<Since C<3.30>>
+
+=over 4
+
+=item text example 1
+
+  package main;
+
+  use Venus 'text';
+
+  # @@ name
+  #
+  # Example Name
+  #
+  # @@ end
+  #
+  # @@ titles #1
+  #
+  # Example Title #1
+  #
+  # @@ end
+  #
+  # @@ titles #2
+  #
+  # Example Title #2
+  #
+  # @@ end
+
+  my $text = text 'name';
+
+  # "Example Name"
+
+=back
+
+=over 4
+
+=item text example 2
+
+  package main;
+
+  use Venus 'text';
+
+  # @@ name
+  #
+  # Example Name
+  #
+  # @@ end
+  #
+  # @@ titles #1
+  #
+  # Example Title #1
+  #
+  # @@ end
+  #
+  # @@ titles #2
+  #
+  # Example Title #2
+  #
+  # @@ end
+
+  my $text = text 'titles', '#1';
+
+  # "Example Title #1"
+
+=back
+
+=over 4
+
+=item text example 3
+
+  package main;
+
+  use Venus 'text';
+
+  # @@ name
+  #
+  # Example Name
+  #
+  # @@ end
+  #
+  # @@ titles #1
+  #
+  # Example Title #1
+  #
+  # @@ end
+  #
+  # @@ titles #2
+  #
+  # Example Title #2
+  #
+  # @@ end
+
+  my $text = text undef, 'name';
+
+  # "Example Name"
+
+=back
+
+=cut
+
 =head2 then
 
   then(Str | Object | CodeRef $self, Any @args) (Any)
