@@ -179,7 +179,7 @@ sub first {
 sub get {
   my ($self, @args) = @_;
 
-  return $self->value if !int@args;
+  return $self->value if !@args;
 
   my ($index) = @args;
 
@@ -295,6 +295,16 @@ sub map {
   return wantarray ? (@$result) : $result;
 }
 
+sub merge {
+  my ($self, @rvalues) = @_;
+
+  require Venus;
+
+  my $lvalue = [@{$self->get}];
+
+  return Venus::merge($lvalue, @rvalues);
+}
+
 sub none {
   my ($self, $code) = @_;
 
@@ -498,10 +508,14 @@ sub rsort {
 sub set {
   my ($self, @args) = @_;
 
-  return $self->value if !int@args;
+  return $self->value if !@args;
+
+  return $self->value(@args) if @args == 1 && ref $args[0] eq 'ARRAY';
 
   my ($index, $value) = @args;
 
+  return if not defined $index;
+
   return $self->value->[$index] = $value;
 }
 
@@ -2680,6 +2694,42 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 merge
+
+  merge(ArrayRef @data) (ArrayRef)
+
+The merge method returns an array reference where the elements in the array and
+the elements in the argument(s) are merged. This operation performs a deep
+merge and clones the datasets to ensure no side-effects.
+
+I<Since C<3.30>>
+
+=over 4
+
+=item merge example 1
+
+  # given: synopsis;
+
+  my $merge = $array->merge([10..15]);
+
+  # [10..15,7,8,9]
+
+=back
+
+=over 4
+
+=item merge example 2
+
+  # given: synopsis;
+
+  my $merge = $array->merge([1,2,{1..4},4..9]);
+
+  # [1,2,{1..4},4..9]
+
+=back
+
+=cut
+
 =head2 ne
 
   ne(Any $arg) (Bool)
