@@ -14,9 +14,9 @@ with 'Venus::Role::Stashable';
 
 use overload (
   '""' => 'explain',
-  'eq' => sub{$_[0]->message eq "$_[1]"},
-  'ne' => sub{$_[0]->message ne "$_[1]"},
-  'qr' => sub{qr/@{[quotemeta($_[0]->message)]}/},
+  'eq' => sub{$_[0]->render eq "$_[1]"},
+  'ne' => sub{$_[0]->render ne "$_[1]"},
+  'qr' => sub{qr/@{[quotemeta($_[0]->render)]}/},
   '~~' => 'explain',
   fallback => 1,
 );
@@ -131,7 +131,7 @@ sub explain {
   $self->trace(1, 1) if !@{$self->frames};
 
   my $frames = $self->{'$frames'};
-  my $message = $self->message;
+  my $message = $self->render;
 
   my @stacktrace = "$message" =~ s/^\s+|\s+$//gr;
 
@@ -252,6 +252,20 @@ sub frame {
   };
 }
 
+sub render {
+  my ($self) = @_;
+
+  my $message = $self->message;
+  my $stashed = $self->stash;
+
+  while (my($key, $value) = each(%$stashed)) {
+    my $token = quotemeta $key;
+    $message =~ s/\{\{\s*$token\s*\}\}/$value/g;
+  }
+
+  return $message;
+}
+
 sub throw {
   my ($self, @args) = @_;
 
@@ -1115,6 +1129,36 @@ I<Since C<1.11>>
 
 =cut
 
+=head2 render
+
+  render() (Str)
+
+The render method replaces tokens in the message with values from the stash and
+returns the formatted string. The token style and formatting operation is
+equivalent to the L<Venus::String/render> operation.
+
+I<Since C<3.30>>
+
+=over 4
+
+=item render example 1
+
+  # given: synopsis
+
+  package main;
+
+  $error->message('Signal received: {{signal}}');
+
+  $error->stash(signal => 'SIGKILL');
+
+  my $render = $error->render;
+
+  # "Signal received: SIGKILL"
+
+=back
+
+=cut
+
 =head2 throw
 
   throw(Any @data) (Error)
