@@ -75,13 +75,8 @@ sub assertion {
 sub config {
   my ($self, $package) = @_;
 
-  $package ||= $self->package or do {
-    my $throw;
-    $throw = $self->throw;
-    $throw->name('on.config');
-    $throw->message('No suitable JSON package');
-    $throw->error;
-  };
+  $package ||= $self->package
+    or $self->throw('error_on_config')->error;
 
   $package = $package->new
     ->canonical
@@ -235,6 +230,17 @@ sub TO_BOOL {
   return Venus::Boolean::TO_BOOL_JPO($value);
 }
 
+# ERRORS
+
+sub error_on_config {
+  my ($self) = @_;
+
+  return {
+    name => 'on.config',
+    message => 'No suitable JSON package',
+  };
+}
+
 1;
 
 
@@ -371,6 +377,34 @@ I<Since C<0.01>>
 
 =cut
 
+=head1 ERRORS
+
+This package may raise the following errors:
+
+=cut
+
+=over 4
+
+=item error: C<error_on_config>
+
+This package may raise an error_on_config exception.
+
+B<example 1>
+
+  # given: synopsis;
+
+  my $error = $json->throw('error_on_config')->catch('error');
+
+  # my $name = $error->name;
+
+  # "on_config"
+
+  # my $message = $error->message;
+
+  # "No suitable JSON package"
+
+=back
+
 =head1 AUTHORS
 
 Awncorp, C<awncorp@cpan.org>
